/*global define*/
/*jslint browser:true*/
define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!de_epages/dhlintraship/ui/packstation-test',
    'jquery',
    'de_epages/dhlintraship/ui/packstation',
    'ep/ui/input'
], function (QUnit, fixture, $, packstation) {

    'use strict';

    QUnit.module("de_epages/dhlintraship/ui/packstation", {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    ep.ajax = function (o) {
        var result = $.Deferred();

        if (o.data && o.data.ViewAction === 'JSONViewPackstations') {
            if (o.data.ObjectID === "18188") {
                result.resolve([{
                    "address": "Engelplatz 8",
                    "city": "Jena",
                    "distance": "1451",
                    "district": "West",
                    "latitude": "50.9261126",
                    "longitude": "11.5826798",
                    "name": "Im Eingangsbereich der Postfachanlage",
                    "packstationId": "103",
                    "zipcode": "07743"
                }, {
                    "address": "Salvador-Allende-Platz 23",
                    "city": "Jena",
                    "distance": "11554",
                    "district": "Lobeda",
                    "latitude": "50.8829539",
                    "longitude": "11.6188628",
                    "name": "An Seitenwand",
                    "packstationId": "110",
                    "zipcode": "07747"
                }]);
            } else {
                result.resolve([]);
            }
        }

        return result;
    };

    QUnit.asyncTest('Show DHLIntraship packstation service results to pick up the package (2 points found)', 6, function () {

        // We have to fake (use sinon.js) the POST request to get data
        var responseString = '[' +
                '{ "address" : "Engelplatz 8", "city" : "Jena", "distance" : "1451", "district" : "West", "latitude" : "50.9261126", "longitude" : "11.5826798", "name" : "Im Eingangsbereich der Postfachanlage", "packstationId" : "103", "zipcode" : "07743" }, ' +
                '{ "address" : "Salvador-Allende-Platz 23", "city" : "Jena", "distance" : "11554", "district" : "Lobeda", "latitude" : "50.8829539", "longitude" : "11.6188628", "name" : "An Seitenwand", "packstationId" : "110", "zipcode" : "07747" }' +
            ']',
            response = JSON.parse(responseString);

        $('#DHLIntrashipPackstation')
            .dhlintrashipUiPackstation({
                packstationSelector : $('#DHLIntrashipPackstation'),
                street: 'Heinrich-Heine-Str.',
                streetNo: '1',
                city: 'Jena',
                zipcode: '07749',
                packstationId: '18188'
            });

        setTimeout(function () {

        	var enablePackstationP = $('#EnableDHLIntrashipPackstation').parent();
        	QUnit.ok(!enablePackstationP.hasClass('HideElementSoft'), "Class HideElementSoft has been removed.");

        	QUnit.equal(
                    $('.map_canvas').length,
                    1,
                    'Check if the map item exists'
            );


            QUnit.ok(
                    $('.map_canvas *').length,
                    'Check if the map item is not empty'
            );

            QUnit.equal(
                    $('.locations tr').length,
                    Object.keys(response).length + 4, // 2 packstations + 4 further information rows
                    '2 rows with packstations in the table'
            );

            QUnit.equal(
                $('.locations tr:eq(0) input[name=location]').val(),
                response[0].packstationId + "|" + response[0].name + "|" + response[0].address + "|" + response[0].zipcode + "|" + response[0].city,
                'Check value of the first radio element: Im Eingangsbereich der Postfachanlage'
            );

            QUnit.equal(
                $('.locations tr:eq(1) input[name=location]').val(),
                response[1].packstationId + "|" + response[1].name + "|" + response[1].address + "|" + response[1].zipcode + "|" + response[1].city,
                'Check value of the second radio element: Salvador-Allende-Platz 23'
            );

            QUnit.start();
        }, 5000);

    });

    QUnit.asyncTest('Show DHLIntraship packstation service results to pick up the package (NO point found)', 2, function () {

        $('#DHLIntrashipPackstation')
        .dhlintrashipUiPackstation({
            packstationSelector : $('#DHLIntrashipPackstation'),
            street: 'Heinrich-Heine-Str.',
            streetNo: '1',
            city: 'Jena',
            zipcode: '07749',
            packstationId: '18189'
        });

        setTimeout(function () {

        	var enablePackstationP = $('#EnableDHLIntrashipPackstation').parent();
        	QUnit.ok(enablePackstationP.hasClass('HideElementSoft'), "Class HideElementSoft has not been removed.");

            QUnit.equal(
                $('#DHLPackstation p').length,
                1,
                'Check that there is an error paragraph'
            );

            QUnit.start();
        }, 5000);

    });
});