#========================================================================================
# package      DE_EPAGES::GoogleAnalytics::Hooks::Shop
# state        public
# description  Sets Google Analytics attributes of the shop.
#========================================================================================
package DE_EPAGES::GoogleAnalytics::Hooks::Shop;

use strict;

#========================================================================================
# function     OnBeforePatchUnityShop
#----------------------------------------------------------------------------------------
# syntax       OnBeforePatchUnityShop( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook API_BeforePatchUnityShop.
#               Sets the Google Analytics content that should be patched to the Unity database.
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameters
#               <ul>
#                 <li>Values  - new shop values                   - ref.hash
#                 <li>Content - content to patch to the unity API - ref.hash
#               </ul>
#========================================================================================
sub OnBeforePatchUnityShop {
    my ($hParams) = @_;
    my $hValues = $hParams->{'Values'};
    my $hContent = $hParams->{'Content'};

    # add elements for patching GoogleAnalytics tracking ID here
    if (exists $hValues->{'GoogleAnalyticsWebPropertyID'}) {
        $hContent->{'userSettings'}->{'googleAnalytics'}->{'trackingId'}
            = $hValues->{'GoogleAnalyticsWebPropertyID'} // '';
    }

    return;
}

1;