#========================================================================================
# package      DE_EPAGES::PayPal::t::unit::Referrer_check
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for DE_EPAGES::PayPal::UI::Shop::_TestRefererUrl
#========================================================================================
package DE_EPAGES::PayPal::t::unit::Referrer_check;
use base DE_EPAGES::Test::API::UnitTest::Test;

use DE_EPAGES::Test::Mock::MockifyServlet;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;
use Test::Exception;

use DE_EPAGES::PayPal::UI::Shop;
use strict;
## no critic (ProtectPrivateSubs)
sub test {
    my $self = shift;

    $self->test_PayPalLiveAccount();
    $self->test_PayPalTestAccount();
    $self->test_PayPalLiveAccount_False();
    $self->test_PayPalLiveAccount_False_with_TestURL();
    $self->test_PayPalTestAccount_False();

    $self->test_securepayments_PayPalLiveAccount();
    $self->test_securepayments_PayPalTestAccount();

    $self->test_SSL_missing();

    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_PayPalLiveAccount {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Url = 'https://www.paypal.com/abc';
    my $TestMode = 0;
    my $LineItemPaymentPayPal = $self->_createLineItemPaymentPayPal($TestMode);
    my $Servlet = $self->_createServlet($Url);
    is(DE_EPAGES::PayPal::UI::Shop::_TestRefererUrl($Servlet, $LineItemPaymentPayPal), undef,"$SubTestName - Prove for live mode that the paypal url is mathching.");
}
#----------------------------------------------------------------------------------------
sub test_PayPalTestAccount {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Url = 'https://www.sandbox.paypal.com/abc';
    my $TestMode = 1;
    my $LineItemPaymentPayPal = $self->_createLineItemPaymentPayPal($TestMode);
    my $Servlet = $self->_createServlet($Url);
    is(DE_EPAGES::PayPal::UI::Shop::_TestRefererUrl($Servlet, $LineItemPaymentPayPal), undef,"$SubTestName - Prove for test mode that the paypal url is mathching.");
}
#----------------------------------------------------------------------------------------
sub test_PayPalLiveAccount_False {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Url = 'https://www.paypal.wrong.de';
    my $TestMode = 0;
    my $LineItemPaymentPayPal = $self->_createLineItemPaymentPayPal($TestMode);
    my $Servlet = $self->_createServlet($Url);
    throws_ok( sub { DE_EPAGES::PayPal::UI::Shop::_TestRefererUrl($Servlet, $LineItemPaymentPayPal) },
                   qr@ HTTP_REFERER is not mapping.: actualUrl=https://www.paypal.wrong.de; expected=@,
                   "$SubTestName - Prove for live mode that a non paypal url is throwing an error."
    );
}
#----------------------------------------------------------------------------------------
sub test_PayPalLiveAccount_False_with_TestURL {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Url = 'https://www.sandbox.paypal.com/abc';
    my $TestMode = 0;
    my $LineItemPaymentPayPal = $self->_createLineItemPaymentPayPal($TestMode);
    my $Servlet = $self->_createServlet($Url);
    throws_ok( sub { DE_EPAGES::PayPal::UI::Shop::_TestRefererUrl($Servlet, $LineItemPaymentPayPal) },
                   qr@ HTTP_REFERER is not mapping.: actualUrl=https://www.sandbox.paypal.com/abc; expected=@,
                   "$SubTestName - Prove for live mode that the test server paypal url is throwing an error."
    );
}
#----------------------------------------------------------------------------------------
sub test_PayPalTestAccount_False {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Url = 'https://www.wrong.de';
    my $TestMode = 1;
    my $LineItemPaymentPayPal = $self->_createLineItemPaymentPayPal($TestMode);
    my $Servlet = $self->_createServlet($Url);
    throws_ok( sub { DE_EPAGES::PayPal::UI::Shop::_TestRefererUrl($Servlet, $LineItemPaymentPayPal) },
                   qr@ HTTP_REFERER is not mapping. \(Testmode\): actualUrl=https://www.wrong.de; expected=@,
                   "$SubTestName - Prove for test mode that a non paypal url is throwing an error."
    );
}
#----------------------------------------------------------------------------------------
sub test_securepayments_PayPalLiveAccount {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Url = 'https://securepayments.paypal.com/abc';
    my $TestMode = 0;
    my $LineItemPaymentPayPal = $self->_createLineItemPaymentPayPal($TestMode);
    my $Servlet = $self->_createServlet($Url);
    is(DE_EPAGES::PayPal::UI::Shop::_TestRefererUrl($Servlet, $LineItemPaymentPayPal), undef, "$SubTestName - Prove for live mode that the securepayments.paypal url is mathching.");
}
#----------------------------------------------------------------------------------------
sub test_securepayments_PayPalTestAccount {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Url = 'https://www.securepayments.sandbox.paypal.com/abc';
    my $TestMode = 1;
    my $LineItemPaymentPayPal = $self->_createLineItemPaymentPayPal($TestMode);
    my $Servlet = $self->_createServlet($Url);
    is(DE_EPAGES::PayPal::UI::Shop::_TestRefererUrl($Servlet, $LineItemPaymentPayPal), undef, "$SubTestName - Prove for test mode that the securepayments.paypal url is mathching.)");
}

#----------------------------------------------------------------------------------------
sub test_SSL_missing {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Servlet = $self->_createServlet();
    throws_ok( sub { DE_EPAGES::PayPal::UI::Shop::_TestRefererUrl($Servlet) },
                   qr@PARAMETER_MISSING: Missing parameter \(Is SSL activated\?\) HttpReferer@,
                   "$SubTestName - Prove that a missing HTTP_REFERER is throwing an error"
    );
}

#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------

sub _createServlet {
    my $self = shift;
    my ($URL) = @_;
    my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop',{
    });
    my $Shop = $MockifyEpagesObject->getMockObject();
    my $MockifyServlet = DE_EPAGES::Test::Mock::MockifyServlet->new( $Shop );
    $MockifyServlet->mock('params', $URL ,[{'string' => 'HTTP_REFERER'}]);
    return $MockifyServlet->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createLineItemPaymentPayPal {
    my $self = shift;
    my ($IsInTestMode) = @_;

    my $hAttributes = {
        'IsTestTransaction' => $IsInTestMode,
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::PayPal::API::Object::LineItemPaymentPayPal',
        $hAttributes
    );

    return $Mockify->getMockObject();
}
__PACKAGE__->runScript();