#==============================================================================
# package      DE_EPAGES::Paybox::UI::PaymentMethodPaybox
# state        private
#==============================================================================
package DE_EPAGES::Paybox::UI::PaymentMethodPaybox;
use base DE_EPAGES::Payment::UI::PaymentMethod;

use strict;

use DE_EPAGES::Core::API::Error                                         qw (GetError ExistsError);
use DE_EPAGES::Core::API::Log                                           qw (LogError);
use DE_EPAGES::ExternalPayment::API::PaymentTypeMethods                 qw (GetPaymentTypeMethodsGroups
                                                                            GetSelectedPaymentTypeMethodID);
use DE_EPAGES::Paybox::API::Constants                             qw (NO_PAYMENT_TYPE
                                                                            FEATURE_LIMIT_EXCEEDED
                                                                            UNKNOWN_ERROR);
use DE_EPAGES::Paybox::API::PaymentMethodGenerator;
use DE_EPAGES::Shop::API::Url                                           qw (BuildShopUrl);

#==============================================================================

sub ViewSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $PaymentMethod = $Servlet->object;
    my $Shop = $PaymentMethod->getSite();

    $Servlet->vars(
        'UpdateURL',
        BuildShopUrl(
            $Shop,
            {   'ChangeAction'  => 'PaymentCallbackPaybox'},
            {   'UseSSL'        => 1,
                'UseObjectPath' => 1,
            },
        )
    );
    $Servlet->vars(
        'PaymentTypeMethodsGroups',
        GetPaymentTypeMethodsGroups($PaymentMethod->get('PaymentType'), $Servlet->languageID),
    );
    $Servlet->vars(
        'PaymentTypeMethod',
        GetSelectedPaymentTypeMethodID( $PaymentMethod )
    );

    my $PaymentMethods = $Shop->folder('PaymentMethods')->children;

    foreach my $PaymentMethod (@$PaymentMethods) {

        next unless $PaymentMethod->class->alias eq 'PaymentMethodPaybox';

        my $PaymentTypeMethodID = GetSelectedPaymentTypeMethodID( $PaymentMethod );
        next unless defined $PaymentTypeMethodID;

        $Servlet->vars('ExistingPayboxMethod_'.$PaymentTypeMethodID, 1);
    }

    return;
}

sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;
    my $PaymentMethod = $Servlet->object;
    my $Form = $Servlet->form;

    # some form checks here
    $Form->form($PaymentMethod, 'PayboxSettings');

    #--- standard save
    $self->Save($Servlet);
}

sub NewPayboxMethod {
    my $self = shift;
    my ($Servlet) = @_;

    my $PaymentMethod           = $Servlet->object();
    my $Form                    = $Servlet->form;
    my $Values                  = $Form->formValues();
    my $aSelectedPaymentTypes   = $Values->{'PaymentMethodToGenerateID'};

    eval {
        my $PaymentMethodGenerator = DE_EPAGES::Paybox::API::PaymentMethodGenerator->new();
        $PaymentMethodGenerator->generatePaymentMethods($PaymentMethod, $aSelectedPaymentTypes);
        my $aNewPaymentMethods = $PaymentMethodGenerator->getGeneratedPaymentMethods();
        $Servlet->vars('NewPaymentMethods', $aNewPaymentMethods);
    };
    if (ExistsError()) {
        my $Error = GetError();
        $Error->vars->{'ShopAlias'} = $PaymentMethod->getSite()->alias;

        if ($Error->code eq NO_PAYMENT_TYPE or $Error->code eq FEATURE_LIMIT_EXCEEDED) {
            $Form->executeFormError({
                'Reason'=> $Error->code,
                'Name'  => $Error->code,
            });
        } else {
            LogError($Error);
            $Form->executeFormError({
                'Reason'=> UNKNOWN_ERROR,
                'Name'  => UNKNOWN_ERROR,
            });
        }
    }

    return;
}

1;
