#========================================================================================
# package      DE_EPAGES::Shop::t::unit::Url
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  unit test for Url.pm
#========================================================================================
package DE_EPAGES::Shop::t::unit::Url;
use base DE_EPAGES::Core::API::Test;
use DE_EPAGES::Shop::API::Url qw ( BuildShopUrl BuildDefaultShopUrl );
use DE_EPAGES::Test::Mock::EpagesObject;
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;

use strict;

# test plan
sub test {
    my $self = shift;

    $self->test_MobileURL();
    $self->test_SF_URL();
    $self->test_SF_Mobile_URL_without_Servlet();

    done_testing();
    return;
}

#----------------------------------------------------------------------------------------
sub test_MobileURL {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Object = $self->_buildObjectWithShopAndWebServerScriptUrl();
    my $IsMobile = 1;
    my $Servlet = $self->_createServlet( $IsMobile );

    my $ShopURL = BuildShopUrl( $Object, {}, { 'Type' => 'sf/mobile', }, $Servlet );

    my $ExpectedURL = 'http://demo.intern.epages.de/epages/DemoShop.mobile/?ObjectID=123456';
    is( $ShopURL, $ExpectedURL, "$SubTestName - test if we get the mobile URL if the serverVariables->SCRIPT_NAME is mobile and type is sf/mobile" );
    return;
}

#----------------------------------------------------------------------------------------
sub test_SF_URL {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Object = $self->_buildObjectWithShopAndWebServerScriptUrl( );
    my $IsMobile = 0;
    my $Servlet = $self->_createServlet( $IsMobile );

    my $ShopURL = BuildShopUrl( $Object, {}, { 'Type' => 'sf/mobile', }, $Servlet );

    my $ExpectedURL = 'http://demo.intern.epages.de/epages/DemoShop.sf/?ObjectID=123456';
    is( $ShopURL ,$ExpectedURL, "$SubTestName - test if we get the sf URL if the serverVariables->SCRIPT_NAME is sf and type is sf/mobile" );
    return;
}

#----------------------------------------------------------------------------------------
sub test_SF_Mobile_URL_without_Servlet {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Object = $self->_buildObjectWithShopAndWebServerScriptUrl( );

    my $ShopURL = BuildShopUrl( $Object, {}, { 'Type' => 'sf/mobile', } );

    my $ExpectedURL = 'http://demo.intern.epages.de/epages/DemoShop.sf/?ObjectID=123456';
    is( $ShopURL ,$ExpectedURL, "$SubTestName - test if we get the sf URL if the serverVariables->SCRIPT_NAME is sf and type is sf/mobile" );
    return;
}

#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------

sub _buildObjectWithShopAndWebServerScriptUrl {
    my $self = shift;
    my $Shop = $self->_createShop( );
    my $Object = $self->_createObject($Shop);
    return $Object;
}

#----------------------------------------------------------------------------------------
sub _createObject {
    my $self = shift;
    my ($Shop) = @_;
    my $hAtributes = {
        'ID' => 123456,
        'Site' => $Shop,
        'instanceOf' => 'ShopObject'
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new( 'DE_EPAGES::Shop::API::Object::ShopObject', $hAtributes );
    $Mockify->addMock(
        'getShopUrl',
        sub {
            my $self = shift;
            my ($hParams, $hOptions, $MyShop) = @_;

            return BuildDefaultShopUrl($self, $hParams, $hOptions, $MyShop);
        });
    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createShop {
    my $self = shift;
    my $hAtributes = {
        'Alias' => 'MyTestShop',
        'instanceOf' => 'Shop',
        'WebServerScriptUrl' => 'http://demo.intern.epages.de/epages/DemoShop.sf',
    };
    my $Shop = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Shop::API::Object::Shop', $hAtributes );
    return $Shop;
}

#----------------------------------------------------------------------------------------
sub _createServlet {
    my $self = shift;
    my ( $IsMobile ) = @_;
    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::Presentation::Servlet::PageType',
                   $aParameterList
              );
    $Mockify->addMockWithReturnValueAndParameterCheck( 'vars', $IsMobile, [{'string'=> 'IsMobile'}] );
    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();
